@@ -4,7 +4,7 @@ from typing import Union
 from .exceptions import InvalidCredentials, NotLoggedIn
 
 
-def catch_error(resp: requests.Response, service="prism") -> requests.resp:
+def catch_error(resp: requests.Response, service="prism") -> requests.Response:
     """Handle errors from backend api
 
     Args:
