@@ -49,7 +49,7 @@ class PrismCLI(object):
         """
         Login with your cofactor credentials.
 
-        Login in with your email and password.
+        Login in with your email address and password.
 
         Examples:
             >>> prism login
@@ -240,7 +240,11 @@ class PrismCLI(object):
         Delete an uploaded fastq file from Cofactor Genomics' cloud storage.
 
         Examples:
-        >>> prism delete test_project
+            >>> prism delete test_project
+
+        Args:
+            project (str): Project name, must not include special characters.
+            file_name (str): Fatsq file name to delete from Cofactor Genomics' cloud storage.
         """
 
         @catch_errors
@@ -340,6 +344,10 @@ class PrismCLI(object):
             >>> prism download upload_test /home/project_folder
             Downloaded: project_test_raw_all_values.csv
             Downloaded: TG19DH-pos1a_10M_sequence1_sample_report.pdf
+
+        Args:
+            project (str): Project name, must not include special characters.
+            local_directory (str): full or relative file path of where files will be downloaded to.
         """
 
         @catch_errors
